const path = require('path');
const webpack = require('webpack');
const WebpackBaseConfig = require('./Base');

class WebpackStagingConfig extends WebpackBaseConfig {
  constructor() {
    super();
    this.config = {
      cache: false,
      devtool: 'eval',
      plugins: [
        new webpack.DefinePlugin({
          'process.env.NODE_ENV': '"staging"'
        }),
        new webpack.LoaderOptionsPlugin({
          minimize: true
        }),
        new webpack.NoEmitOnErrorsPlugin(),
        new webpack.optimize.AggressiveMergingPlugin(),
        new webpack.optimize.UglifyJsPlugin({
          compress: {
            warnings: false
          }
        })
      ]
    };

    // Deactivate hot-reloading if we run production build on the development server
    this.config.devServer.hot = false;
  }

  /**
   * Get the environment name
   * @return {String} The current environment
   */
  get env() {
    return 'staging';
  }
}

module.exports = WebpackStagingConfig;
